@@ -141,14 +141,23 @@ class AsyncRecommendingAppContentDispenser:
         self.ahead_recommender = AheadRecommender(recommender=recommender)
         self.movie_markdown_generator = movie_markdown_generator
         self.movie_id = self.ahead_recommender.movie_id
-        self._initial_content = None
+        self._initial_content = self.movie_markdown_generator(item_id=self.movie_id)
         self.next_content = None
 
     def initial_content(self):
-        if self._initial_content is not None:
-            return self._initial_content
-        self._initial_content = self.movie_markdown_generator(item_id=self.movie_id)
-        self.next_content = asyncio.create_task(self.content_ahead())
+        """A workaround to gradio mechanics to create_task on app.launch() and not on initialization."""
+        if self.next_content is None:
+            try:
+                self.next_content = asyncio.create_task(self.content_ahead())
+            except RuntimeError:
+                pass
+        return self._initial_content
+
+    def initial_poster_url(self):
+        return self.initial_content()[1]
+
+    def initial_markdown(self):
+        return self.initial_content()[0]
 
     async def content_ahead(self):
         with wandb_timeit("recommending"):
@@ -160,6 +169,8 @@ class AsyncRecommendingAppContentDispenser:
     async def content(self, feedback: Feedback, session: Session):
         wandb.log(dict(movie_id=self.movie_id, rating=feedback.int, session=session.id))
         self.ahead_recommender.save_rating(movie_id=self.movie_id, rating=feedback.int)
+        if self.next_content is None:
+            self.next_content = asyncio.create_task(self.content_ahead())
         self.movie_id, markdown, poster_url = await self.next_content
         self.next_content = asyncio.create_task(self.content_ahead())
         return markdown, poster_url
@@ -175,10 +186,11 @@ def build_app_blocks(
     gr.Markdown("This movie recommender adapts to your preferences")
     session = gr.State(value=Session())
     with gr.Row():
-        image = gr.Image(lambda: dispenser.initial_content()[1], interactive=False)
+        first_movie_markdown, first_image_url = dispenser.initial_content
+        image = gr.Image(first_image_url, interactive=False)
         image.style(width=200)
         with gr.Column(scale=4):
-            markdown = gr.Markdown(lambda: dispenser.initial_content()[0])
+            markdown = gr.Markdown(first_movie_markdown)
 
             def build_button(feedback):
                 async def wrapper(session):
